Function Backup-NexusSSL {
  [CmdletBinding()]
  Param(
    [Parameter()]
    [String]
    $BackupLocation = $(Join-Path $env:UserProfile "NexusSSLBackup")
  )

  begin {

    if (-not (Test-Path $BackupLocation)) {
      Write-Host "Creating SSL Backup location"
      $null = New-Item $BackupLocation -ItemType Directory
    }

  }

  process {

    if (Test-Path "$env:ProgramData\nexus\etc\ssl\keystore.jks") {
      Copy-Item "$env:ProgramData\nexus\etc\ssl\keystore.jks" $BackupLocation
    }
    
    if (Test-Path "$env:ProgramData\nexus\etc\jetty\jetty-https.xml") {
      Copy-Item "$env:ProgramData\nexus\etc\jetty\jetty-https.xml" $BackupLocation
    }

  }


}

Function Restore-NexusSSL {
  [CmdletBinding()]
  Param(
    [Parameter()]
    [String]
    $BackupLocation = $(Join-Path $env:UserProfile "NexusSSLBackup")
  )

  process {
    Write-Host "Shutting down nexus Service to re-apply ssl configuration"
    $null = Stop-Service nexus

    Write-Host "Reapplying SSL Configuration"
    if (Test-Path "$BackupLocation\keystore.jks") {
      Copy-Item "$BackupLocation\keystore.jks" "$env:ProgramData\nexus\etc\ssl"
    }
    
    if (Test-Path "$BackupLocation\jetty-https.xml") {
      Copy-Item "$BackupLocation\jetty-https.xml" "$env:ProgramData\nexus\etc\jetty"
    }

  Write-Host "Nexus is now available with the restored SSL configuration"

  }
}